<?php

namespace Payroll\Allowance\Http\Controllers;
use Litepie\Allowance\Http\Requests\AllowanceRequest;
use Litepie\Allowance\Models\Allowance;

trait AllowanceWorkflow {
	
    /**
     * Workflow controller function for allowance.
     *
     * @param Model   $allowance
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AllowanceRequest $request, Allowance $allowance, $step)
    {

        try {

            $allowance->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('allowance::allowance.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/allowance/allowance/' . $allowance->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/allowance/allowance/' . $allowance->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for allowance.
     *
     * @param Model   $allowance
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Allowance $allowance, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $allowance->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('allowance::allowance.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('allowance::admin.allowance.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('allowance::admin.allowance.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('allowance::admin.allowance.message', $data)->render();

        }

    }
}