<?php

namespace Payroll\Allowance\Policies;

use App\User;
use Payroll\Allowance\Models\Allowance;

class AllowancePolicy
{

    /**
     * Determine if the given user can view the allowance.
     *
     * @param User $user
     * @param Allowance $allowance
     *
     * @return bool
     */
    public function view(User $user, Allowance $allowance)
    {
        if ($user->canDo('allowance.allowance.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $allowance->user_id;
    }

    /**
     * Determine if the given user can create a allowance.
     *
     * @param User $user
     * @param Allowance $allowance
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('allowance.allowance.create');
    }

    /**
     * Determine if the given user can update the given allowance.
     *
     * @param User $user
     * @param Allowance $allowance
     *
     * @return bool
     */
    public function update(User $user, Allowance $allowance)
    {
        if ($user->canDo('allowance.allowance.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $allowance->user_id;
    }

    /**
     * Determine if the given user can delete the given allowance.
     *
     * @param User $user
     * @param Allowance $allowance
     *
     * @return bool
     */
    public function destroy(User $user, Allowance $allowance)
    {
        if ($user->canDo('allowance.allowance.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $allowance->user_id;
    }

    /**
     * Determine if the given user can verify the given allowance.
     *
     * @param User $user
     * @param Allowance $allowance
     *
     * @return bool
     */
    public function verify(User $user, Allowance $allowance)
    {
        if ($user->canDo('allowance.allowance.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('allowance.allowance.verify') 
        && $user->is('manager')
        && $allowance->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given allowance.
     *
     * @param User $user
     * @param Allowance $allowance
     *
     * @return bool
     */
    public function approve(User $user, Allowance $allowance)
    {
        if ($user->canDo('allowance.allowance.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
