<?php

namespace Payroll\Allowance\Providers;

use Illuminate\Support\ServiceProvider;

class AllowanceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'allowance');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'allowance');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('allowance', function ($app) {
            return $this->app->make('Payroll\Allowance\Allowance');
        });

        // Bind Allowance to repository
        $this->app->bind(
            'Payroll\Allowance\Interfaces\AllowanceRepositoryInterface',
            \Payroll\Allowance\Repositories\Eloquent\AllowanceRepository::class
        );

        $this->app->register(\Payroll\Allowance\Providers\AuthServiceProvider::class);
        $this->app->register(\Payroll\Allowance\Providers\EventServiceProvider::class);
        $this->app->register(\Payroll\Allowance\Providers\RouteServiceProvider::class);
        // $this->app->register(\Payroll\Allowance\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['allowance'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('payroll/allowance.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/allowance')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/allowance')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
